@@ -58,7 +58,7 @@ void TextBrowser::setSource(const QUrl &name)
         uri.replace(QRegExp(QLatin1String("^([^:]+:)/+")), QStringLiteral("\\1"));
     }
 
-    if (uri.startsWith(QStringLiteral("ATTACH:"))) {
+    if (uri.startsWith(QLatin1String("ATTACH:"))) {
         Q_EMIT attachmentUrlClicked(uri);
     } else {
         UriHandler::process(uri);
@@ -154,7 +154,7 @@ IncidenceViewer::IncidenceViewer(QWidget *parent)
 void IncidenceViewer::init()
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     d->mBrowser->setOpenLinks(true);
     d->mBrowser->setMinimumHeight(1);
@@ -222,7 +222,7 @@ void IncidenceViewer::setIncidence(const Akonadi::Item &incidence, const QDate &
 
 void IncidenceViewer::itemChanged(const Akonadi::Item &item)
 {
-    if (!item.hasPayload<KCalCore::Incidence::Ptr>()) {
+    if (!item.hasPayload<KCalendarCore::Incidence::Ptr>()) {
         d->mBrowser->clear();
         return;
     }
